==> quarkus-logging-json-3.10.2-sources.jar: io/quarkus/logging/json/runtime/JsonLogConfig$JsonConfig$$accessor.java <==
package io.quarkus.logging.json.runtime;
@io.quarkus.Generated("Quarkus annotation processor")
public final class JsonLogConfig$JsonConfig$$accessor {
    private JsonLogConfig$JsonConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enable(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).enable;
    }
    @SuppressWarnings("unchecked")
    public static void set_enable(Object __instance, boolean enable) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).enable = enable;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_prettyPrint(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).prettyPrint;
    }
    @SuppressWarnings("unchecked")
    public static void set_prettyPrint(Object __instance, boolean prettyPrint) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).prettyPrint = prettyPrint;
    }
    @SuppressWarnings("unchecked")
    public static Object get_dateFormat(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).dateFormat;
    }
    @SuppressWarnings("unchecked")
    public static void set_dateFormat(Object __instance, Object dateFormat) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).dateFormat = (String)dateFormat;
    }
    @SuppressWarnings("unchecked")
    public static Object get_recordDelimiter(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).recordDelimiter;
    }
    @SuppressWarnings("unchecked")
    public static void set_recordDelimiter(Object __instance, Object recordDelimiter) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).recordDelimiter = (java.util.Optional<String>)recordDelimiter;
    }
    @SuppressWarnings("unchecked")
    public static Object get_zoneId(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).zoneId;
    }
    @SuppressWarnings("unchecked")
    public static void set_zoneId(Object __instance, Object zoneId) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).zoneId = (String)zoneId;
    }
    @SuppressWarnings("unchecked")
    public static Object get_exceptionOutputType(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).exceptionOutputType;
    }
    @SuppressWarnings("unchecked")
    public static void set_exceptionOutputType(Object __instance, Object exceptionOutputType) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).exceptionOutputType = (org.jboss.logmanager.formatters.StructuredFormatter.ExceptionOutputType)exceptionOutputType;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_printDetails(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).printDetails;
    }
    @SuppressWarnings("unchecked")
    public static void set_printDetails(Object __instance, boolean printDetails) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).printDetails = printDetails;
    }
    @SuppressWarnings("unchecked")
    public static Object get_keyOverrides(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).keyOverrides;
    }
    @SuppressWarnings("unchecked")
    public static void set_keyOverrides(Object __instance, Object keyOverrides) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).keyOverrides = (java.util.Optional<String>)keyOverrides;
    }
    @SuppressWarnings("unchecked")
    public static Object get_excludedKeys(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).excludedKeys;
    }
    @SuppressWarnings("unchecked")
    public static void set_excludedKeys(Object __instance, Object excludedKeys) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).excludedKeys = (java.util.Optional<java.util.Set<String>>)excludedKeys;
    }
    @SuppressWarnings("unchecked")
    public static Object get_additionalField(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).additionalField;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalField(Object __instance, Object additionalField) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).additionalField = (java.util.Map<String, AdditionalFieldConfig>)additionalField;
    }
}

==> quarkus-logging-json-3.18.2-sources.jar: io/quarkus/logging/json/runtime/JsonLogConfig$JsonConfig$$accessor.java <==
package io.quarkus.logging.json.runtime;
@io.quarkus.Generated("Quarkus annotation processor")
public final class JsonLogConfig$JsonConfig$$accessor {
    private JsonLogConfig$JsonConfig$$accessor() {}
    @SuppressWarnings("unchecked")
    public static boolean get_enable(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).enable;
    }
    @SuppressWarnings("unchecked")
    public static void set_enable(Object __instance, boolean enable) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).enable = enable;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_prettyPrint(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).prettyPrint;
    }
    @SuppressWarnings("unchecked")
    public static void set_prettyPrint(Object __instance, boolean prettyPrint) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).prettyPrint = prettyPrint;
    }
    @SuppressWarnings("unchecked")
    public static Object get_dateFormat(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).dateFormat;
    }
    @SuppressWarnings("unchecked")
    public static void set_dateFormat(Object __instance, Object dateFormat) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).dateFormat = (String)dateFormat;
    }
    @SuppressWarnings("unchecked")
    public static Object get_recordDelimiter(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).recordDelimiter;
    }
    @SuppressWarnings("unchecked")
    public static void set_recordDelimiter(Object __instance, Object recordDelimiter) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).recordDelimiter = (java.util.Optional<String>)recordDelimiter;
    }
    @SuppressWarnings("unchecked")
    public static Object get_zoneId(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).zoneId;
    }
    @SuppressWarnings("unchecked")
    public static void set_zoneId(Object __instance, Object zoneId) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).zoneId = (String)zoneId;
    }
    @SuppressWarnings("unchecked")
    public static Object get_exceptionOutputType(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).exceptionOutputType;
    }
    @SuppressWarnings("unchecked")
    public static void set_exceptionOutputType(Object __instance, Object exceptionOutputType) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).exceptionOutputType = (org.jboss.logmanager.formatters.StructuredFormatter.ExceptionOutputType)exceptionOutputType;
    }
    @SuppressWarnings("unchecked")
    public static boolean get_printDetails(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).printDetails;
    }
    @SuppressWarnings("unchecked")
    public static void set_printDetails(Object __instance, boolean printDetails) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).printDetails = printDetails;
    }
    @SuppressWarnings("unchecked")
    public static Object get_keyOverrides(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).keyOverrides;
    }
    @SuppressWarnings("unchecked")
    public static void set_keyOverrides(Object __instance, Object keyOverrides) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).keyOverrides = (java.util.Optional<String>)keyOverrides;
    }
    @SuppressWarnings("unchecked")
    public static Object get_excludedKeys(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).excludedKeys;
    }
    @SuppressWarnings("unchecked")
    public static void set_excludedKeys(Object __instance, Object excludedKeys) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).excludedKeys = (java.util.Optional<java.util.Set<String>>)excludedKeys;
    }
    @SuppressWarnings("unchecked")
    public static Object get_additionalField(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).additionalField;
    }
    @SuppressWarnings("unchecked")
    public static void set_additionalField(Object __instance, Object additionalField) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).additionalField = (java.util.Map<String, AdditionalFieldConfig>)additionalField;
    }
    @SuppressWarnings("unchecked")
    public static Object get_logFormat(Object __instance) {
        return ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).logFormat;
    }
    @SuppressWarnings("unchecked")
    public static void set_logFormat(Object __instance, Object logFormat) {
        ((io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig)__instance).logFormat = (io.quarkus.logging.json.runtime.JsonLogConfig.JsonConfig.LogFormat)logFormat;
    }
}
